@@ -34,8 +34,14 @@ typedef struct {
 
 G_DEFINE_TYPE_WITH_PRIVATE (DhApp, dh_app, GTK_TYPE_APPLICATION);
 
-/******************************************************************************/
-
+/**
+ * dh_app_peek_book_manager:
+ * @app: a #DhApp object
+ *
+ * Get the associated #DhBookManager.
+ *
+ * Returns: (transfer none): the book manager associated with this
+ */
 DhBookManager *
 dh_app_peek_book_manager (DhApp *app)
 {
@@ -48,6 +54,14 @@ dh_app_peek_book_manager (DhApp *app)
         return priv->book_manager;
 }
 
+/**
+ * dh_app_peek_first_window:
+ * @app: a #DhApp object
+ *
+ * Get the first #DhWindow.
+ *
+ * Returns: (transfer none): the first window
+ */
 GtkWindow *
 dh_app_peek_first_window (DhApp *app)
 {
@@ -70,6 +84,14 @@ dh_app_peek_first_window (DhApp *app)
         return dh_app_peek_first_window (app);
 }
 
+/**
+ * dh_app_peek_assistant:
+ * @app: a #DhApp object
+ *
+ * Get the associated #DhAssistant.
+ *
+ * Returns: (transfer none): the assistant
+ */
 GtkWindow *
 dh_app_peek_assistant (DhApp *app)
 {
@@ -114,6 +136,12 @@ _dh_app_has_app_menu (DhApp *app)
 /******************************************************************************/
 /* Application action activators */
 
+/**
+ * dh_app_new_window:
+ * @app: a #DhApp object
+ *
+ * Create a new #DhWindow.
+ */
 void
 dh_app_new_window (DhApp *app)
 {
@@ -122,6 +150,12 @@ dh_app_new_window (DhApp *app)
         g_action_group_activate_action (G_ACTION_GROUP (app), "new-window", NULL);
 }
 
+/**
+ * dh_app_quit:
+ * @app: a #DhApp object
+ *
+ * Quit the application.
+ */
 void
 dh_app_quit (DhApp *app)
 {
@@ -130,6 +164,13 @@ dh_app_quit (DhApp *app)
         g_action_group_activate_action (G_ACTION_GROUP (app), "quit", NULL);
 }
 
+/**
+ * dh_app_search:
+ * @app: a #DhApp object
+ * @keyword: the search request
+ *
+ * Search for @keyword in the entire application.
+ */
 void
 dh_app_search (DhApp *app,
                const gchar *keyword)
@@ -139,6 +180,13 @@ dh_app_search (DhApp *app,
         g_action_group_activate_action (G_ACTION_GROUP (app), "search", g_variant_new_string (keyword));
 }
 
+/**
+ * dh_app_search_assistant:
+ * @app: a #DhApp object
+ * @keyword: the search request
+ *
+ * Search for @keyword in the entire application with a #DhAssistant.
+ */
 void
 dh_app_search_assistant (DhApp *app,
                          const gchar *keyword)
@@ -148,6 +196,12 @@ dh_app_search_assistant (DhApp *app,
         g_action_group_activate_action (G_ACTION_GROUP (app), "search-assistant", g_variant_new_string (keyword));
 }
 
+/**
+ * dh_app_raise:
+ * @app: a #DhApp object
+ *
+ * Present the main window of the application.
+ */
 void
 dh_app_raise (DhApp *app)
 {
@@ -255,7 +309,7 @@ about_cb (GSimpleAction *action,
                                "website-label", _("Devhelp Website"),
                                "logo-icon-name", PACKAGE_TARNAME,
                                "license-type", GTK_LICENSE_GPL_2_0,
-                               "copyright", "Copyright 2001-2016 – the Devhelp team",
+                               "copyright", "Copyright 2001-2017 – the Devhelp team",
                                NULL);
 }
 
@@ -466,6 +520,13 @@ dh_app_activate (GApplication *application)
 
 /******************************************************************************/
 
+/**
+ * dh_app_new:
+ *
+ * Create a new #DhApp object.
+ *
+ * Returns: a new #DhApp object
+ */
 DhApp *
 dh_app_new (void)
 {
@@ -509,7 +570,7 @@ static GOptionEntry options[] = {
 
 static gint
 dh_app_handle_local_options (GApplication *app,
-                             GVariantDict *options)
+                             GVariantDict *local_options)
 {
   if (option_version)
     {
@@ -528,13 +589,13 @@ dh_app_command_line (GApplication            *app,
         const gchar *option_search = NULL;
         const gchar *option_search_assistant = NULL;
         gboolean option_quit = FALSE;
-        GVariantDict *options;
+        GVariantDict *options_dict;
 
-        options = g_application_command_line_get_options_dict (command_line);
-        g_variant_dict_lookup (options, "new-window", "b", &option_new_window);
-        g_variant_dict_lookup (options, "search", "&s", &option_search);
-        g_variant_dict_lookup (options, "search-assistant", "&s", &option_search_assistant);
-        g_variant_dict_lookup (options, "quit", "b", &option_quit);
+        options_dict = g_application_command_line_get_options_dict (command_line);
+        g_variant_dict_lookup (options_dict, "new-window", "b", &option_new_window);
+        g_variant_dict_lookup (options_dict, "search", "&s", &option_search);
+        g_variant_dict_lookup (options_dict, "search-assistant", "&s", &option_search_assistant);
+        g_variant_dict_lookup (options_dict, "quit", "b", &option_quit);
 
         if (option_new_window) {
                 dh_app_new_window (DH_APP (app));
