@@ -68,7 +68,7 @@ static guint tab_accel_keys[] = {
 static const
 struct
 {
-        gchar *name;
+        const gchar *name;
         double level;
 }
 zoom_levels[] =
@@ -306,7 +306,7 @@ window_get_current_zoom_level_index (DhWindow *window)
         WebKitWebView *web_view;
         double previous;
         double zoom_level = ZOOM_DEFAULT;
-        int i;
+        guint i;
 
         web_view = window_get_active_web_view (window);
         if (web_view != NULL)
@@ -521,7 +521,7 @@ static GActionEntry win_entries[] = {
         { "find-next",        find_next_cb },
 
         /* view */
-        { "show-sidebar",     NULL, NULL, "false", show_sidebar_cb },
+        { "show-sidebar",     NULL, NULL, "true", show_sidebar_cb },
         { "zoom-in",          zoom_in_cb },
         { "zoom-out",         zoom_out_cb },
         { "zoom-default",     zoom_default_cb },
@@ -656,7 +656,7 @@ dh_window_init (DhWindow *window)
         DhWindowPrivate  *priv;
         GtkAccelGroup *accel_group;
         GClosure      *closure;
-        gint           i;
+        guint          i;
 
         gtk_widget_init_template (GTK_WIDGET (window));
 
@@ -733,6 +733,12 @@ dh_window_class_init (DhWindowClass *klass)
 
         klass->open_link = dh_window_open_link;
 
+        /**
+         * DhWindow::open-link:
+         * @window: a #DhWindow object
+         * @location: the location of the link
+         * @flags: a #DhOpenLinkFlags
+         */
         signals[OPEN_LINK] =
                 g_signal_new ("open-link",
                               G_TYPE_FROM_CLASS (klass),
@@ -1276,7 +1282,7 @@ window_web_view_tab_accel_cb (GtkAccelGroup   *accel_group,
 {
         DhWindowPrivate *priv;
         gint page_num;
-        gint i;
+        guint i;
 
         priv = dh_window_get_instance_private (window);
 
@@ -1550,6 +1556,14 @@ window_tab_set_title (DhWindow      *window,
         }
 }
 
+/**
+ * dh_window_new:
+ * @application: the #DhApp owning this window
+ *
+ * Create a new #DhWindow object.
+ *
+ * Returns: a new #DhWindow object
+ */
 GtkWidget *
 dh_window_new (DhApp *application)
 {
@@ -1575,6 +1589,13 @@ dh_window_new (DhApp *application)
         return GTK_WIDGET (window);
 }
 
+/**
+ * dh_window_search:
+ * @window: a #DhWindow object
+ * @str: the string to search
+ *
+ * Search for @str in the current window.
+ */
 void
 dh_window_search (DhWindow    *window,
                   const gchar *str)
@@ -1588,7 +1609,15 @@ dh_window_search (DhWindow    *window,
         dh_sidebar_set_search_string (priv->sidebar, str);
 }
 
-/* Only call this with a URI that is known to be in the docs. */
+/*< private >
+ * _dh_window_display_uri:
+ * @window: a #DhWindow object
+ * @uri: the uri to display
+ *
+ * Open the @uri in the current window.
+ *
+ * Only call this with a URI that is known to be in the docs.
+ */
 void
 _dh_window_display_uri (DhWindow    *window,
                         const gchar *uri)
